.. _api-reference:

=============
API Reference
=============

.. module:: outcome

.. autofunction:: capture

.. autofunction:: acapture

.. autoclass:: Outcome
   :members:
   :inherited-members:

.. autoclass:: Value
   :members:
   :inherited-members:

.. autoclass:: Error
   :members:
   :inherited-members:

.. autoclass:: AlreadyUsedError
